==> haskell-unagi-streams-0.2.7-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unagi-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unagi-streams
version:              0.2.7
visibility:           public
id:                   unagi-streams-0.2.7-CDMqLHlRNK0EBrszQTzOaD
key:                  unagi-streams-0.2.7-CDMqLHlRNK0EBrszQTzOaD
license:              BSD-3-Clause
copyright:            Bitnomial, Inc. (c) 2016
maintainer:           luke@bitnomial.com
author:               Luke Hoersten
homepage:             https://github.com/bitnomial/unagi-streams
synopsis:             Unagi Chan IO-Streams
description:
    Io-streams chans implemented underneath with
    unagi-chans. This library is a straight port of
    the default io-streams chan implementation.

category:             IO-Streams, Concurrency
abi:                  3a8a282e5cb928423f024e57bcb911c7
exposed:              True
exposed-modules:
    System.IO.Streams.Concurrent.Unagi
    System.IO.Streams.Concurrent.Unagi.Bounded

import-dirs:          /usr/lib/ghc-9.0.2/site-local/unagi-streams-0.2.7
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unagi-streams-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unagi-streams
hs-libraries:         HSunagi-streams-0.2.7-CDMqLHlRNK0EBrszQTzOaD
depends:
    base-4.15.1.0 io-streams-1.5.2.2-ErylTtjTDRr1UcIG8Sg41a
    unagi-chan-0.4.1.4-2lTLeixrKNz2CaoOxiuyvs

haddock-interfaces:
    /usr/share/doc/haskell-unagi-streams/html/unagi-streams.haddock

haddock-html:         /usr/share/doc/haskell-unagi-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unagi-streams-0.2.7-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unagi-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unagi-streams
version:              0.2.7
visibility:           public
id:                   unagi-streams-0.2.7-4JhOVZUVoV9Ip7SMJbdmL3
key:                  unagi-streams-0.2.7-4JhOVZUVoV9Ip7SMJbdmL3
license:              BSD-3-Clause
copyright:            Bitnomial, Inc. (c) 2016
maintainer:           luke@bitnomial.com
author:               Luke Hoersten
homepage:             https://github.com/bitnomial/unagi-streams
synopsis:             Unagi Chan IO-Streams
description:
    Io-streams chans implemented underneath with
    unagi-chans. This library is a straight port of
    the default io-streams chan implementation.

category:             IO-Streams, Concurrency
abi:                  bf2e305f3a4436649e5600de91799722
exposed:              True
exposed-modules:
    System.IO.Streams.Concurrent.Unagi
    System.IO.Streams.Concurrent.Unagi.Bounded

import-dirs:          /usr/lib/ghc-9.0.2/site-local/unagi-streams-0.2.7
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unagi-streams-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unagi-streams
hs-libraries:         HSunagi-streams-0.2.7-4JhOVZUVoV9Ip7SMJbdmL3
depends:
    base-4.15.1.0 io-streams-1.5.2.2-1rmTTD5GyAiGY9hmphDOxR
    unagi-chan-0.4.1.4-GkonEKA0PO5CMWmu54JVE

haddock-interfaces:
    /usr/share/doc/haskell-unagi-streams/html/unagi-streams.haddock

haddock-html:         /usr/share/doc/haskell-unagi-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
